==> inspect-7.x-3.4.tar.gz: inspect/js/inspect_noaction.js <==
/**
 * @file
 * Drupal Inspect module - no-action version
 */

/**
 * @param {func} jQuery
 */
(function($) {
  /**
   * @ignore
   */
  Drupal.inspect = window.Inspect = window.inspect = (function() {
    var _cls = "module-inspect-collapsible", _shw = 1, _fld = 1,
    f;
    /**
     * Does nothing, returns void.
     *
     * @name inspect
     * @constructor
     * @class
     * @singleton
     * @return {void}
     */
    f = function() {};
    /**
     * Use for checking if that window.inspect is actually the one we are looking for (see example).
     * For the noactions type of this script, the value of .tcepsnI is false.
     * The name of the property is just something unlikely to exist (and the class name backwards).
     * @example
//  Check if inspect exists, and that it's the active sort.
if(typeof window.inspect === "function" && inspect.tcepsnI) {
  inspect("whatever");
}
     * @name inspect.tcepsnI
     * @type {bool}
     */
    /**
     * @name inspect.tcepsni
     * @type {bool}
     */
    f.tcepsnI = f.tcepsni = false;
    /**
     * Does nothing, returns void.
     *
     * @deprecated
     * @function
     * @name inspect.variable
     * @return {void}
     */
    /**
     * Does nothing, returns void.
     *
     * @function
     * @name inspect.log
     * @return {void}
     */
    /**
     * Does nothing, returns void.
     *
     * @function
     * @name inspect.trace
     * @return {void}
     */
    /**
     * Does nothing, returns void.
     *
     * @function
     * @name inspect.traceLog
     * @return {void}
     */
    /**
     * Does nothing, returns void.
     *
     * @function
     * @name inspect.events
     * @return {void}
     */
    /**
     * Does nothing, returns void.
     *
     * @function
     * @name inspect.eventsLog
     * @return void
     */
    /**
     * Does nothing, returns void.
     *
     * @function
     * @name inspect.console
     * @return {void}
     */
    /**
     * Does nothing, returns void.
     *
     * @function
     * @name inspect.logMessage
     * @return void
     */
    /**
     * Does nothing, returns void.
     *
     * @function
     * @name inspect.errorHandler
     * @return void
     */
    f.variable = f.log = f.trace = f.traceLog = f.events = f.eventsLog = f.console = f.logMessage = f.errorHandler = function() {};
    /**
     * Does nothing, returns empty string.
     *
     * @deprecated
     * @function
     * @name inspect.variableGet
     * @return {str}
     */
    /**
     * Does nothing, returns empty string.
     *
     * @function
     * @name inspect.get
     * @return {str}
     */
    /**
     * Does nothing, returns empty string.
     *
     * @function
     * @name inspect.typeOf
     * @return {str}
     */
    /**
     * Does nothing, returns empty string.
     *
     * @function
     * @name inspect.traceGet
     * @return {void}
     */
    /**
     * Does nothing, returns empty string.
     *
     * @function
     * @name inspect.argsGet
     * @return {str}
     */
    /**
     * Does nothing, returns empty string.
     *
     * @function
     * @name inspect.eventsGet
     * @return {str}
     */
    f.variableGet = f.get = f.typeOf = f.traceGet = f.argsGet = f.eventsGet = function() {
      return "";
    };
    /**
     * Empty object.
     *
     * @name inspect.browser
     * @type {obj}
     */
    f.browser = {};
    /**
      * Toggle display of all inspection outputs on current page.
      *
      * This function is always implemented, even for no-action no-fold.
      *
      * @function
      * @name inspect.toggleOutput
      * @return {void}
      */
    f.toggleDisplay = function() {
      var u;
      if(_shw > 0) {
        $("." + _cls).hide();
      }
      else if(_fld < 0) {
        $("pre."+ _cls).show();
      }
      else {
        $("pre."+ _cls).each(function(){
          $((u = $(this).prev("div."+ _cls).get(0)) ? u : this).show();
        });
      }
      _shw *= -1;
    };
    /**
      * Toggle inspection folding, unless folding is disabled.
      *
      * Folding is not supported for IE<9.
      *
      * @function
      * @name inspect.toggleFolding
      * @return {void}
      */
    f.toggleFolding = function() {
      var u;
      if(!(u = Drupal.settings.inspect) || !u.foldingOff) {
        if(_fld > 0) {
          $("div." + _cls).hide();
          $("pre." + _cls).show();
        }
        else {
          $("pre." + _cls).hide();
          $("div." + _cls).show();
        }
        _fld *= -1;
        _shw = 1;
      }
    };

    return f;
  })();
})(jQuery);

==> inspect-7.x-4.1.tar.gz: inspect/js/inspect_noaction.js <==
/**
 * @file
 * Drupal Inspect module - no-action version
 */

/**
 * @param {func} jQuery
 */
(function($) {
  /**
   * @ignore
   */
  Drupal.inspect = window.Inspect = window.inspect = (function() {
    var _cls = "module-inspect-collapsible", _shw = 1, _fld = 1,
    f;
    /**
     * Does nothing, returns void.
     *
     * @name inspect
     * @constructor
     * @class
     * @singleton
     * @return {void}
     */
    f = function() {};
    /**
     * Use for checking if that window.inspect is actually the one we are looking for (see example).
     * For the noactions type of this script, the value of .tcepsnI is false.
     * The name of the property is just something unlikely to exist (and the class name backwards).
     * @example
//  Check if inspect exists, and that it's the active sort.
if(typeof window.inspect === "function" && inspect.tcepsnI) {
  inspect("whatever");
}
     * @name inspect.tcepsnI
     * @type {bool}
     */
    /**
     * @name inspect.tcepsni
     * @type {bool}
     */
    f.tcepsnI = f.tcepsni = false;
    /**
     * Does nothing, returns void.
     *
     * @function
     * @name inspect.log
     * @return {void}
     */
    /**
     * Does nothing, returns void.
     *
     * @function
     * @name inspect.trace
     * @return {void}
     */
    /**
     * Does nothing, returns void.
     *
     * @function
     * @name inspect.traceLog
     * @return {void}
     */
    /**
     * Does nothing, returns void.
     *
     * @function
     * @name inspect.events
     * @return {void}
     */
    /**
     * Does nothing, returns void.
     *
     * @function
     * @name inspect.eventsLog
     * @return void
     */
    /**
     * Does nothing, returns void.
     *
     * @function
     * @name inspect.console
     * @return {void}
     */
    /**
     * Does nothing, returns void.
     *
     * @function
     * @name inspect.logMessage
     * @return void
     */
    /**
     * Does nothing, returns void.
     *
     * @function
     * @name inspect.errorHandler
     * @return void
     */
    f.log = f.trace = f.traceLog = f.events = f.eventsLog = f.console = f.logMessage = f.errorHandler = function() {};
    /**
     * Does nothing, returns empty string.
     *
     * @function
     * @name inspect.get
     * @return {str}
     */
    /**
     * Does nothing, returns empty string.
     *
     * @function
     * @name inspect.typeOf
     * @return {str}
     */
    /**
     * Does nothing, returns empty string.
     *
     * @function
     * @name inspect.traceGet
     * @return {void}
     */
    /**
     * Does nothing, returns empty string.
     *
     * @function
     * @name inspect.argsGet
     * @return {str}
     */
    /**
     * Does nothing, returns empty string.
     *
     * @function
     * @name inspect.eventsGet
     * @return {str}
     */
    f.get = f.typeOf = f.traceGet = f.argsGet = f.eventsGet = function() {
      return "";
    };
    /**
     * Empty object.
     *
     * @name inspect.browser
     * @type {obj}
     */
    f.browser = {};
    /**
      * Toggle display of all inspection outputs on current page.
      *
      * This function is always implemented, even for no-action no-fold.
      *
      * @function
      * @name inspect.toggleOutput
      * @return {void}
      */
    f.toggleDisplay = function() {
      var u;
      if(_shw > 0) {
        $("." + _cls).hide();
      }
      else if(_fld < 0) {
        $("pre."+ _cls).show();
      }
      else {
        $("pre."+ _cls).each(function(){
          $((u = $(this).prev("div."+ _cls).get(0)) ? u : this).show();
        });
      }
      _shw *= -1;
    };
    /**
      * Toggle inspection folding, unless folding is disabled.
      *
      * Folding is not supported for IE<9.
      *
      * @function
      * @name inspect.toggleFolding
      * @return {void}
      */
    f.toggleFolding = function() {
      var u;
      if(!(u = Drupal.settings.inspect) || !u.foldingOff) {
        if(_fld > 0) {
          $("div." + _cls).hide();
          $("pre." + _cls).show();
        }
        else {
          $("pre." + _cls).hide();
          $("div." + _cls).show();
        }
        _fld *= -1;
        _shw = 1;
      }
    };

    return f;
  })();
})(jQuery);
